@@ -118,117 +118,6 @@ QVariant PublicTransport::busStationFromLocation(const KPublicTransport::Locatio
     return PublicTransport::placeFromLocation<KItinerary::BusStation>(loc);
 }
 
-QString PublicTransport::lineIcon(const QVariant &line) const
-{
-    using namespace KPublicTransport;
-    const auto l = line.value<Line>();
-    const auto logo = l.logo();
-    if (!logo.isEmpty()) {
-        return logo;
-    }
-    const auto modeLogo = l.modeLogo();
-    if (!modeLogo.isEmpty()) {
-        return modeLogo;
-    }
-    return lineModeIcon(l.mode());
-}
-
-QString PublicTransport::lineModeIcon(int lineMode) const
-{
-    using namespace KPublicTransport;
-    switch (lineMode) {
-        case Line::Air:
-            return QStringLiteral("qrc:///images/flight.svg");
-        case Line::Boat:
-        case Line::Ferry:
-            return QStringLiteral("qrc:///images/ferry.svg");
-        case Line::Bus:
-            return QStringLiteral("qrc:///images/bus.svg");
-        case Line::BusRapidTransit:
-        case Line::Coach:
-            return QStringLiteral("qrc:///images/coach.svg");
-        case Line::Funicular:
-            return QStringLiteral("qrc:///images/Funicular.svg");
-        case Line::LocalTrain:
-        case Line::Train:
-            return QStringLiteral("qrc:///images/train.svg");
-        case Line::LongDistanceTrain:
-            return QStringLiteral("qrc:///images/longdistancetrain.svg");
-        case Line::Metro:
-            return QStringLiteral("qrc:///images/subway.svg");
-        case Line::RailShuttle:
-        case Line::RapidTransit:
-            return QStringLiteral("qrc:///images/rapidtransit.svg");
-        case Line::Shuttle:
-            return QStringLiteral("qrc:///images/shuttle.svg");
-        case Line::Taxi:
-            return QStringLiteral("qrc:///images/taxi.svg");
-        case Line::Tramway:
-            return QStringLiteral("qrc:///images/tramway.svg");
-        case Line::RideShare:
-            return QStringLiteral("qrc:///images/car.svg");
-    }
-
-    return QStringLiteral("question");
-}
-
-QString PublicTransport::rentalVehicleIcon(const KPublicTransport::RentalVehicle &vehicle) const
-{
-    using namespace KPublicTransport;
-    switch (vehicle.type()) {
-        case RentalVehicle::Unknown:
-            return {};
-        case RentalVehicle::Bicycle:
-        case RentalVehicle::Pedelec: // TODO
-            return QStringLiteral("qrc:///images/bike.svg");
-        case RentalVehicle::ElectricMoped:
-        case RentalVehicle::ElectricKickScooter:
-            return QStringLiteral("question"); // TODO
-        case RentalVehicle::Car:
-            return QStringLiteral("qrc:///images/car.svg");
-    }
-    return QStringLiteral("question");
-}
-
-static QString individualTransportIcon(const KPublicTransport::IndividualTransport &it)
-{
-    using namespace KPublicTransport;
-
-    switch (it.mode()) {
-        case IndividualTransport::Bike:
-             return QStringLiteral("qrc:///images/bike.svg");
-        case IndividualTransport::Car:
-            return QStringLiteral("qrc:///images/car.svg");
-        case IndividualTransport::Walk:
-            return QStringLiteral("qrc:///images/walk.svg");
-    }
-
-    return QStringLiteral("question");
-}
-
-QString PublicTransport::journeySectionIcon(const KPublicTransport::JourneySection &journeySection) const
-{
-    using namespace KPublicTransport;
-    switch (journeySection.mode()) {
-        case JourneySection::Invalid:
-            break;
-        case JourneySection::PublicTransport:
-            return lineIcon(journeySection.route().line());
-        case JourneySection::Walking:
-            return QStringLiteral("qrc:///images/walk.svg");
-        case JourneySection::Waiting:
-            return QStringLiteral("qrc:///images/wait.svg");
-        case JourneySection::Transfer:
-            return QStringLiteral("qrc:///images/transfer.svg");
-        case JourneySection::RentedVehicle:
-            return rentalVehicleIcon(journeySection.rentalVehicle());
-        case JourneySection::IndividualTransport:
-            return individualTransportIcon(journeySection.individualTransport());
-    }
-
-    return QStringLiteral("question");
-}
-
 QString PublicTransport::journeySectionLabel(const KPublicTransport::JourneySection &journeySection) const
 {
     using namespace KPublicTransport;
@@ -672,4 +561,14 @@ QList<QGeoCoordinate>PublicTransport::pathToGeoCoordinates(const KPublicTranspor
     return result;
 }
 
+KPublicTransport::Load::Category PublicTransport::maximumOccupancy(const QList<KPublicTransport::LoadInfo> &loadInfo)
+{
+    using namespace KPublicTransport;
+    auto o = Load::Unknown;
+    for (const auto &l : loadInfo) {
+        o = std::max(o, l.load());
+    }
+    return o;
+}
+
 #include "moc_publictransport.cpp"
